@@ -23,7 +23,7 @@ default_hosts = ('127.0.0.1', '::1')
 default_settings = (
     ('enabled', asbool, 'true'),
     ('intercept_exc', asbool, 'true'),
-    ('intercept_redirects', asbool, 'true'),
+    ('intercept_redirects', asbool, 'false'),
     ('panels', as_globals_list, default_panel_names),
     ('hosts', as_list, default_hosts),
     )
